<?php
/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software: you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with OrangeHRM.
 * If not, see <https://www.gnu.org/licenses/>.
 */

namespace OrangeHRM\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Table("ohrm_email_notification")
 * @ORM\Entity
 */
class EmailNotification
{
    public const LEAVE_APPLICATION = 1;
    public const LEAVE_ASSIGNMENT = 2;
    public const LEAVE_APPROVAL = 3;
    public const LEAVE_CANCELLATION = 4;
    public const LEAVE_REJECTION = 5;

    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private int $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=120, nullable=false)
     */
    private string $name;

    /**
     * @var bool
     *
     * @ORM\Column(name="is_enable", type="integer", nullable=false)
     */
    private bool $enabled;

    /**
     * @var EmailSubscriber[]
     *
     * @ORM\OneToMany(targetEntity="OrangeHRM\Entity\EmailSubscriber", mappedBy="emailNotification")
     */
    private iterable $emailSubscribers;

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    /**
     * @param int $id
     */
    public function setId(int $id): void
    {
        $this->id = $id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(string $name): void
    {
        $this->name = $name;
    }

    /**
     * @return bool
     */
    public function isEnabled(): bool
    {
        return $this->enabled;
    }

    /**
     * @param bool $enabled
     */
    public function setEnabled(bool $enabled): void
    {
        $this->enabled = $enabled;
    }

    /**
     * @return EmailSubscriber[]
     */
    public function getEmailSubscribers(): iterable
    {
        return $this->emailSubscribers;
    }
}
